.. Atlas Download Tools documentation master file, created by
   sphinx-quickstart on Mon Aug  2 14:34:17 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Atlas Download Tools
====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/installation
   source/getting_started
   source/synchronization

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   source/api/atldld


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
